---
title: <span class="badge object-type-scalar"></span> DatetimeLocal
---
# <span class="badge object-type-scalar"></span> DatetimeLocal

Date & time: Datetime local

## Definition

```python
# Date & time: Datetime local
DatetimeLocal: typing.Literal["dateTimeAsLocal"] = "dateTimeAsLocal"
```
